@@ -11,14 +11,8 @@
 
 import argparse
 import os.path
-try:
-  import requests
-except:
-  try:
-    import urllib2
-  except:
-    pass
 import platform
+import re
 import subprocess
 import sys
 
@@ -27,6 +21,7 @@ import unit_test
 abs_top_builddir = os.environ.get( 'abs_top_builddir' )
 abs_top_srcdir = os.environ.get( 'abs_top_srcdir' )
 abs_srcdir = os.environ.get( 'abs_srcdir' )
+abs_testerdir = os.environ.get( 'abs_testerdir' )
 builddir = os.environ.get( 'builddir' )
 prog_matlab = os.environ.get( 'MATLAB' )
 prog_octave = os.environ.get( 'OCTAVE', 'octave' )
@@ -35,10 +30,23 @@ prog_python = os.environ.get( 'PYTHON', sys.executable )
 
 unit_tester = unit_test.unit_test( )
 
+def find_target_path( lang, target ):
+  global abs_top_builddir
+
+  abs_top_builddir_native = os.path.normpath(abs_top_builddir)
+  dirs = [ os.path.join( abs_top_builddir_native, lang, 'module', target ),
+           os.path.join( abs_top_builddir_native,  lang, target ) ]
+
+  for path in dirs:
+    if ( os.path.exists( path ) ):
+      return path
+  return None
+
 def set_globals( args ):
   global abs_top_builddir
   global abs_top_srcdir
   global abs_srcdir
+  global abs_testerdir
   global builddir
   global prog_matlab
 
@@ -48,18 +56,52 @@ def set_globals( args ):
     abs_top_srcdir = args.abs_top_srcdir
   if ( args.abs_srcdir ):
     abs_srcdir = args.abs_srcdir
+  if ( args.abs_testerdir ):
+    abs_testerdir = args.abs_testerdir
   if ( args.builddir ):
     builddir = args.builddir
 
   if ( args.matlab ):
     prog_matlab = args.matlab
 
+# Python program to compare two version number
+# Method to compare two versions.
+# Return 1 if v2 is smaller,
+# -1 if v1 is smaller,,
+# 0 if equal
+def versionCompare(v1, v2):
+
+    # This will split both the versions by '.'
+    arr1 = v1.split(".")
+    arr2 = v2.split(".")
+
+    # Initializer for the version arrays
+    i = 0
+
+    # We have taken into consideration that both the
+    # versions will contains equal number of delimiters
+    while(i < len(arr1)):
+
+        # Version 2 is greater than version 1
+        if int(arr2[i]) > int(arr1[i]):
+            return -1
+
+        # Version 1 is greater than version 2
+        if int(arr1[i]) > int(arr2[i]):
+            return 1
+
+        # We can't conclude till now
+        i += 1
+
+    # Both the versions are equal
+    return 0
+
 class Skip( Exception ):
   EXIT_CODE = 77
 
   def __init__( self, value ):
     self.value = value
-    
+
   def __str__( self ):
     return str( self.value )
 
@@ -93,15 +135,15 @@ class server( object ):
 class null_server( server ):
   def __init__( self ):
     global unit_tester
-    global abs_top_srcdir
+    global abs_testerdir
 
     sep = '/'
     super( self.__class__, self ).__init__( )
-    if ( not abs_top_srcdir ):
-      raise Skip( 'Unset variable  abs_top_srcdir' )
-    if ( os.sep in abs_top_srcdir ):
+    if ( not abs_testerdir ):
+      raise Skip( 'Unset variable  abs_testerdir' )
+    if ( os.sep in abs_testerdir ):
       sep = os.sep
-    self.script = sep.join( [ abs_top_srcdir, 'tests', 'null_server.py' ] )
+    self.script = sep.join( [ abs_testerdir, 'null_server.py' ] )
     if ( not os.path.exists( self.script ) ):
       raise Skip( 'Server (%s) does not exist' \
                     % self.script )
@@ -122,16 +164,15 @@ class null_server( server ):
 class nds1_mock_server( server ):
   def __init__( self ):
     global unit_tester
-    global abs_top_srcdir
+    global abs_testerdir
 
     sep = '/'
     super( self.__class__, self ).__init__( )
-    if ( not abs_top_srcdir ):
-      raise Skip( 'Unset variable  abs_top_srcdir' )
-    if ( os.sep in abs_top_srcdir ):
+    if ( not abs_testerdir ):
+      raise Skip( 'Unset variable  abs_testerdir' )
+    if ( os.sep in abs_testerdir ):
       sep = os.sep
-    #self.script = sep.join( [ abs_top_srcdir, 'swig', 'common', 'test', 'mockup_server.py' ] )
-    self.script = sep.join( [ abs_top_srcdir, 'tests', 'mockup_server.py' ] )
+    self.script = sep.join( [ abs_testerdir, 'mockup_server.py' ] )
     ## unit_tester.msg_info( 'nds1_mock_server script: %s' % ( self.script ) )
     if ( not os.path.exists( self.script ) ):
       raise Skip( 'Server (%s) does not exist' \
@@ -156,7 +197,7 @@ class replay_server( server ):
   DEFAULT_PROTOCOL = None
 
   def __init__( self, args ):
-    global abs_top_srcdir
+    global abs_testerdir
 
     super( self.__class__, self ).__init__( )
     self.proc = None
@@ -165,7 +206,7 @@ class replay_server( server ):
     self.json_filename = args.replay_json_filename
     self.protocol = args.replay_protocol
     if ( not self.test_dir ):
-      self.test_dir = os.path.join( abs_top_srcdir, 'tests' )
+      self.test_dir = os.path.join( abs_testerdir )
     if ( self.json_filename ):
       self.json_filename = os.path.join( self.test_dir,
                                          'test-json',
@@ -181,18 +222,10 @@ class replay_server( server ):
         #------------------------------------------------------------
         # Leave as the last sanity check since it may take the longest
         #------------------------------------------------------------
-        if ( self.blob_remote_cache.startswith( '/' ) ):
-          if ( not os.path.isdir( self.blob_remote_cache ) ):
-            raise( Skip( "Unable to find cache directory - %s " %
-                         ( self.blob_remote_cache ) ) )
-        elif ( 'requests' in sys.modules ):
-          r = requests.get(self.blob_remote_cache, stream=True, timeout=5 )
-          for chunk in r.iter_content(chunk_size=1024):
-            # Read off the buffer
-            pass
-        elif ( 'urllib2' in sys.modules ):
-          response = urllib2.urlopen( self.blob_remote_cache )
-          chunk = response.read( )
+        # if ( self.blob_remote_cache.startswith( '/' ) ):
+        if ( not os.path.isdir( self.blob_remote_cache ) ):
+          raise( Skip( "Unable to find cache directory - %s " %
+                       ( self.blob_remote_cache ) ) )
           
       except Exception as Error:
         raise( Skip( 'Unable to connect to blob cache - %s' % ( str( Error ) ) ) )
@@ -283,7 +316,6 @@ class exe( executor ):
 
 class matlab( executor ):
   def __init__( self, script ):
-    print( "DEBUG: Creating matlab" )
     super( self.__class__, self ).__init__( script )
 
   def eval( self ):
@@ -295,9 +327,8 @@ class matlab( executor ):
     argv = ''
 
     abs_top_builddir_native = os.path.normpath(abs_top_builddir)
-    ndspath = os.path.join( abs_top_builddir_native, 'swig', 'common', 'module' )
+    ndspath = os.path.join( abs_top_builddir_native, 'common', 'module' )
     ndscpath = os.path.join( abs_top_builddir_native, 'src', 'client' )
-    print( "DEBUG: MATLAB eval: %s Platform: %s" % ( prog_matlab, platform.system( ) ) )
     if ( not prog_matlab or prog_matlab == 'PROG_MATLAB-NOTFOUND' ):
       return self.skip( )
     jarfile = java.find_nds2( )
@@ -352,7 +383,6 @@ class matlab( executor ):
     cmd += mscript
     cmd = cmd.strip( )
 
-    print( "DEBUG: MATLAB full command: %s" % str(cmd) )
     try:
       if ( os.path.isfile( diary_filename ) ):
         os.remove( diary_filename )
@@ -378,18 +408,11 @@ class matlab( executor ):
 
   @staticmethod
   def find_path( ):
-    global abs_top_builddir
-
-    lang = 'matlab'
-    target = '+ndsm'
-    abs_top_builddir_native = os.path.normpath(abs_top_builddir)
-    dirs = [ os.path.join( abs_top_builddir_native, 'swig', lang, 'module', target ),
-             os.path.join( abs_top_builddir_native, 'swig', lang, target ) ]
-
-    for dir in dirs:
-      if ( os.path.exists( dir ) ):
-        return os.path.dirname( dir )
-    return None
+    path = find_target_path( lang = 'matlab',
+                             target = '+ndsm' )
+    if ( path ):
+      return os.path.dirname( path )
+    return( path )
       
 
 class octave( executor ):
@@ -436,13 +459,13 @@ class java( executor ):
         global builddir
         global prog_java
 
-        
         script =  ( os.path.basename( self.script ) )
         (script, ext) = os.path.splitext( script )
         jarfile = java.find_nds2( )
+        jversion = java.get_version( )
 
         cmd = "%s " % ( self.prefix )
-        cmd += "%s %s -enableassertions" % ( prog_java, self.debug_flags )
+        cmd += "\"%s\" %s -enableassertions" % ( prog_java, self.debug_flags )
         cmd += " -cp .%s%s.jar%s%s" % ( os.pathsep, os.path.join(
             os.path.normpath( builddir ), script),
                                         os.pathsep, os.path.normpath(
@@ -451,7 +474,6 @@ class java( executor ):
         if ( self.args ):
           cmd += ' ' + ' '.join( self.args )
         cmd = cmd.strip( )
-        # print( "DEBUG: %s" % cmd );
         try:
             output = subprocess.check_output( cmd,
                                               stderr=subprocess.STDOUT,
@@ -462,19 +484,19 @@ class java( executor ):
             return Error.returncode
         return 0
 
+    @staticmethod
+    def get_version( ):
+      global prog_java
+
+      retval = subprocess.check_output([prog_java, "-version"], stderr=subprocess.STDOUT)
+      retval = retval.splitlines()[ 0 ]
+      retval = re.findall('"([^"]*)"', retval)[ 0 ]
+      return retval
+
     @staticmethod
     def find_nds2( ):
-      global abs_top_builddir
-
-      lang = 'java'
-      target = 'nds2.jar'
-
-      dirs = [ os.path.join( abs_top_builddir, 'swig', lang, 'module', target ),
-               os.path.join( abs_top_builddir, 'swig', lang, target ) ]
-      for dir in dirs:
-        if ( os.path.exists( dir ) ):
-          return dir
-      return None
+      return( find_target_path( lang = 'java',
+                                target = 'nds2.jar' ) )
 
 class python( executor ):
     def __init__( self, script ):
@@ -487,8 +509,8 @@ class python( executor ):
 
         lang = 'python'
 
-        dirs = [ os.path.join( abs_top_builddir, 'swig', lang, 'module' ),
-                 os.path.join( abs_top_builddir, 'swig', lang, 'module', '.libs' ) ]
+        dirs = [ os.path.join( abs_top_builddir, lang, 'module' ),
+                 os.path.join( abs_top_builddir, lang, 'module', '.libs' ) ]
 
         if ( 'PYTHONPATH' in os.environ ):
             dirs.append( os.environ['PYTHONPATH'] )
@@ -570,6 +592,10 @@ def main( argv ):
                        help = 'Specify absolute path to the current source directory',
                        action = 'store',
                        default = None )
+  parser.add_argument( '--abs-testerdir',
+                       help = 'Specify absolute path to the tester directory',
+                       action = 'store',
+                       default = None )
   parser.add_argument( '--builddir',
                        help = 'Specify current build directory',
                        action = 'store',
@@ -618,6 +644,8 @@ def main( argv ):
       sargs += [ '--abs-top-srcdir=%s' % args.abs_top_srcdir ]
     if ( args.abs_srcdir ):
       sargs += [ '--abs-srcdir=%s' % args.abs_srcdir ]
+    if ( args.abs_testerdir ):
+      sargs += [ '--abs-testerdir=%s' % args.abs_testerdir ]
     if ( args.builddir ):
       sargs += [ '--builddir=%s' % args.builddir ]
     if ( args.command_prefix ):
