@@ -2,11 +2,6 @@ import binascii
 import gzip
 import hashlib
 
-try:
-    import httplib
-except ImportError:
-    pass  # Not available in version 3
-
 import json
 import os
 import os.path
@@ -64,40 +59,13 @@ class StorageBlob(object):
                     conn = None
                     url = os.environ['REPLAY_BLOB_REMOTE_CACHE'] + "/" + hash + ".gz"
                     print("Searching for blob at %s" % url)
-                    if (url.lower().startswith('/')):
-                        if os.path.exists(url):
-                            # python2.6 cannot use GzipFile with the 'with' statement
-                            gz = gzip.GzipFile(url, "rb")
-                            self.__data = gz.read()
-                            gz.close()
+                    if os.path.exists(url):
+                        # python2.6 cannot use GzipFile with the 'with' statement
+                        gz = gzip.GzipFile(url, "rb")
+                        self.__data = gz.read()
+                        gz.close()
                     else:
-                        if url.lower().startswith('http://'):
-                            url = url[7:]
-                        elif url.lower().startswith('https://'):
-                            raise Exception('https not supported for blob cache, it is already checksumed')
-                        host, remote_path = url.split('/', 1)
-                        if (not httplib):
-                            conn = http.client.HTTPConnection(host, timeout=5)
-                        else:
-                            conn = httplib.HTTPConnection(host, timeout=5)
-                        conn.request("GET", "/" + remote_path)
-                        resp = conn.getresponse()
-                        data = resp.read()
-                        if (resp.status == 200):
-                            print("Found %s in remote cache" % hash)
-                            if not os.path.exists(self.blob_dir):
-                                os.mkdir(self.blob_dir)
-                            gz = open(gzfname, "wb")
-                            gz.write(data)
-                            gz.close()
-
-                            gz = gzip.GzipFile(gzfname, "rb")
-                            self.__data = gz.read()
-                            gz.close()
-
-                        data = ""
-
-                        conn.close()
+                        raise Exception("Unable to find blob in cache")
                 else:
                     raise Exception("Data blob %s was not found please update %s or set REPLAY_BLOB_REMOTE_CACHE" % (
                     hash, self.blob_dir))
@@ -247,6 +215,29 @@ class CompoundScript(object):
             scripts.append(script.serialize())
         return {"type": "compound", "scripts": scripts}
 
+class CompoundMultiConnectScript(object):
+    """A CompoundScript is a container object which executes a series of script like objects"""
+
+    def __init__(self, scripts):
+        self.scripts = scripts
+
+    def call_with_server(self, inp, out, new_conn):
+        first = True
+        for cur in self.scripts:
+            if not first:
+                f = new_conn()
+                inp = f
+                out = f
+            first = False
+            cur(inp, out)
+        print("Compound multi connect script done")
+
+    def serialize(self):
+        scripts = []
+        for script in self.scripts:
+            scripts.append(script.serialize())
+        return {"type": "compound_multi", "scripts": scripts}
+
 
 class NamedScript(object):
     """A Named script is a container that holds a single script object referenced by name from a external script container"""
@@ -262,6 +253,14 @@ class NamedScript(object):
         return {"type": "named", "name": self.name}
 
 
+class NopScript(object):
+    """Does nothing"""
+    def __call__(self, inp, out):
+        return
+
+    def serialize(self):
+        return{"type": "nop"}
+
 class ExternalScript(object):
     """An ExternalScript object loads scripts from the specified external script into the local list of scripts.
     Locally defined scripts have precidence over external scripts"""
@@ -309,7 +308,7 @@ class CommandScript(object):
                 if action.startswith(ext + '.'):
                     CommandScript.modules[ext].validate_action(action[len(ext) + 1:], args)
                     return
-        raise Exception("Unsupported command action and args %s %s" % (action, str(args)))
+        raise Exception("Unsupported command action and args {0} {1}".format(action, args))
 
     def __init__(self, action, args):
         CommandScript.validate_action(action, args)
@@ -362,11 +361,13 @@ def __unserialize_script(data, container):
 
     if data["type"] == "script":
         return Script(data["command"], extract_response(data))
-    elif data["type"] == "compound":
+    elif data["type"] == "compound" or data["type"] == "compound_multi":
         scripts = []
         for script in data["scripts"]:
             scripts.append(__unserialize_script(script, container))
-        return CompoundScript(scripts)
+        if data["type"] == "compound":
+            return CompoundScript(scripts)
+        return CompoundMultiConnectScript(scripts)
     elif data["type"] == "named":
         return NamedScript(data["name"], container)
     elif data["type"] == "external":
@@ -377,6 +378,8 @@ def __unserialize_script(data, container):
         if response is not None:
             args.append(response)
         return CommandScript(data["action"], args)
+    elif data["type"] == "nop" or data["type"] == "comment":
+        return NopScript()
     else:
         raise Exception("Unknown script type %s" % data["type"])
 
