@@ -16,6 +16,6 @@ try:
     dat = c.fetch(1108835634, 1108835634+4, ["X1:E"])
 
 except RuntimeError as e:
-    print "Caught Runtime error, should be a lack of data"
+    print("Caught Runtime error, should be a lack of data")
     sys.exit(0)
 sys.exit(1)
