@@ -12,7 +12,7 @@ try:
     lst = c.find_channels('*')
 
 except RuntimeError as e:
-    print "Caught Runtime error, should be from a timeout, but we currently cannot get a good error message"
+    print("Caught Runtime error, should be from a timeout, but we currently cannot get a good error message")
     sys.exit(0)
-print "Did not test timeouts!!!!"
+print("Did not test timeouts!!!!")
 sys.exit(1)
